<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Instalacja',
'L_WRONG_PHP_VERSION'				=> 'PluXml wymaga PHP 5 lub nowszego, do uruchomienia.',
'L_SELECT_LANG'						=> 'Wybierz język',
'L_INPUT_CHANGE'					=> 'Zmień',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Kategoria 1',
'L_DEFAULT_CATEGORY_URL'			=> 'kategoria-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Strona 1',
'L_DEFAULT_STATIC_URL'				=> 'strona-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Pierwszy post',
'L_DEFAULT_ARTICLE_URL'				=> 'pierwszy-post',
'L_DEFAULT_COMMENT_CONTENT'			=> 'To jest pierwszy komentarz !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml jest już zainstalowany !',
'L_ERR_MISSING_USER'				=> 'Proszę wpisać nazwę !',
'L_ERR_MISSING_LOGIN'				=> 'Proszę wpisać login !',
'L_ERR_MISSING_PASSWORD'			=> 'Proszę wpisać hasło !',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Niepoprawne potwierdzenie hasła',
'L_PLUXML_INSTALLATION'				=> 'Instalacja PluXml',
'L_SITE_DESCRIPTION'				=> 'Blog i CMS oparty na XML !',
'L_VERSION'							=> 'wersja',
'L_USERNAME'						=> 'Nazwa admina',
'L_LOGIN'							=> 'Login admina',
'L_PASSWORD'						=> 'Hasło',
'L_PASSWORD_CONFIRMATION'			=> 'Potwierdź hasło',
'L_INPUT_INSTALL'					=> 'Zainstaluj',
'L_TIMEZONE'						=> 'Strefa czasowa',
'L_PWD_VERY_WEAK'					=> 'Bardzo słabe hasło',
'L_PWD_WEAK'						=> 'Słabe hasło',
'L_PWD_GOOD'						=> 'Dobre hasło',
'L_PWD_STRONG'						=> 'Silne hasło',
);
?>
